IF "%CONDA_BUILD%" == "" (
    call C:\ci\pymongo_1620214310549\work\build_env_setup.bat
)
REM ===== end generated header =====
python setup.py install --single-version-externally-managed --record=record.txt